@@ -32,8 +32,8 @@ gaWrapper<-function(gaArgs=NULL,        # can specify your own outside
   timeStart=Sys.time()
   optpar<- ga(type = "real-valued",
               fitness=targetFinder,
-              min = modelInfo$minBound,
-              max = modelInfo$maxBound,
+              lower = modelInfo$minBound,
+              upper = modelInfo$maxBound,
               pcrossover= gaArgs$pcrossover,
               pmutation=gaArgs$pmutation,
               maxiter=gaArgs$maxiter, 
